@@ -48,7 +48,7 @@
 
 #include "urldata.h"
 #include "cfilters.h"
-#include "sendf.h"
+#include "curl_trc.h"
 #include "hostip.h"
 #include "url.h"
 #include "multiif.h"
