@@ -45,7 +45,7 @@
 #include <signal.h>
 
 #include "urldata.h"
-#include "sendf.h"
+#include "curl_trc.h"
 #include "connect.h"
 #include "hostip.h"
 #include "hash.h"
@@ -56,7 +56,6 @@
 #include "curlx/inet_pton.h"
 #include "multiif.h"
 #include "doh.h"
-#include "curlx/warnless.h"
 #include "progress.h"
 #include "select.h"
 #include "strcase.h"
