@@ -56,6 +56,7 @@
 #include "curlx/dynbuf.h"
 #include "urldata.h"
 #include "sendf.h"
+#include "curl_trc.h"
 #include "hostip.h"
 #include "progress.h"
 #include "transfer.h"
@@ -72,7 +73,6 @@
 #include "url.h"
 #include "bufref.h"
 #include "curl_sasl.h"
-#include "curlx/warnless.h"
 
 
 /* meta key for storing protocol meta at easy handle */
