@@ -31,12 +31,12 @@
 #include "urldata.h"
 #include "url.h"
 #include "sendf.h"
+#include "curl_trc.h"
 #include "cfilters.h"
 #include "connect.h"
 #include "progress.h"
 #include "transfer.h"
 #include "select.h"
-#include "vtls/vtls.h"
 #include "curl_ntlm_core.h"
 #include "escape.h"
 #include "curl_endian.h"
