@@ -33,7 +33,7 @@
 #include "../urldata.h"
 #include "../cfilters.h"
 #include "../cf-socket.h"
-#include "../sendf.h"
+#include "../curl_trc.h"
 #include "../rand.h"
 #include "../multiif.h"
 #include "../connect.h"
@@ -47,7 +47,6 @@
 #include "../transfer.h"
 #include "../url.h"
 #include "../bufref.h"
-#include "../curlx/warnless.h"
 #include "../vtls/openssl.h"
 #include "../vtls/keylog.h"
 #include "../vtls/vtls.h"
